#
# spec file for package midori
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           midori
Version:        0.3.0
Release:        7.13.1
License:        LGPLv2.1
Source:         http://archive.xfce.org/src/apps/%{name}/0.3/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE midori-fix-certificate-file-path.patch bnc#758431 gber@opensuse.org -- Adds the path to the openSUSE CA certificate bundle
Patch0:         midori-fix-certificate-file-path.patch
# PATCH-FIX-OPENSUSE midori-handle-missing-certificate-file.patch bnc#758431 gber@opensuse.org -- Do not reject invalid certificates on the libsoup level when the CA certificate bundle is missing
Patch1:         midori-handle-missing-certificate-file.patch
Group:          Productivity/Networking/Web/Browsers
Summary:        Lightweight Webkit-based Web Browser
Url:            http://twotoasts.de/index.php?/pages/midori_summary.html
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig(unique-1.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(webkit-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  gtk-doc
BuildRequires:  docutils
BuildRequires:  intltool
BuildRequires:  python
BuildRequires:  update-desktop-files
# for rsvg-convert utility
BuildRequires:  rsvg-view
%if 0%{?suse_version} >= 1140
# for valac
BuildRequires:  vala
%endif
Recommends:     %{name}-lang = %{version}
Recommends:     ca-certificates
Recommends:     xdg-utils

%description
Midori is a lightweight web browser based on WebKit and GTK+. Its major
features are:

* Tabs, windows and session management.
* Flexibly configurable Web Search.
* User scripts and user styles support.
* Straightforward bookmark management.
* Customizable and extensible interface.
* Extensions written in C and Vala.

%package devel
License:        LGPLv2.1
Summary:        Development Files for Midori
Group:          Development/Libraries/C and C++
Recommends:     vala

%description devel
This package contains development files needed to develop extensions for
Midori.


%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export CFLAGS="%{optflags}"
# --debug-level=debug is the default an partially overrides CFLAGS
# by specifiying --docdir the HTML help is installed into the right location
./waf configure \
    --nocache \
    --enable-apidocs \
    --debug-level=none \
%if 0%{?suse_version} < 1140
    --disable-vala \
%endif
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir} \
    --localstatedir=%{_localstatedir} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir} \
    --docdir=%{_defaultdocdir}/%{name}
./waf build -v --nocache %{?_smp_mflags}

%install
./waf install --nocache --destdir=%{buildroot}

install -D -p -m 644 HACKING TODO TRANSLATE \
    %{buildroot}%{_defaultdocdir}/%{name}
# API doc needs to be installed manually
install -d -m 755 %{buildroot}%{_datadir}/gtk-doc/html/%{name}
install -D -p -m 644 _build_/docs/api/midori/html/* \
    %{buildroot}%{_datadir}/gtk-doc/html/%{name}

%suse_update_desktop_file -i %{name}

# fix lang: no -> nb
mv %{buildroot}%{_datadir}/locale/{no,nb}
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}
%find_lang %{name}

%clean
rm -rf %{buildroot}

%if 0%{?suse_version} >= 1140

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}
%{_bindir}/%{name}
%dir %{_libdir}/midori
%{_libdir}/midori/*.so
%dir %{_sysconfdir}/xdg/midori
%dir %{_sysconfdir}/xdg/midori/extensions
%dir %{_sysconfdir}/xdg/midori/extensions/libadblock.so
%config(noreplace) %{_sysconfdir}/xdg/midori/search
%config(noreplace) %{_sysconfdir}/xdg/midori/extensions/libadblock.so/config
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/status/news-feed.*
%{_datadir}/icons/hicolor/*/categories/extension.*
%{_datadir}/icons/hicolor/*/apps/%{name}.*

%files devel
%defattr(-,root,root)
%doc %{_datadir}/gtk-doc/html/%{name}
%if 0%{?suse_version} >= 1140
%{_includedir}/midori-0.3
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/history-list.*
%endif

%files lang -f %{name}.lang

%changelog
* Sat Apr 21 2012 gber@opensuse.org
- added midori-fix-certificate-file-path.patch which adds the path
  to the openSUSE CA certificate bundle, added
  midori-handle-missing-certificate-file.patch so that invalid
  certificates are not rejected on the libsoup level when the CA
  certificate bundle is missing and added a dependency on
  ca-certificates (bnc#758431)
* Thu Feb 17 2011 gber@opensuse.org
- call %%icon_theme_cache_post/un
* Tue Feb  1 2011 gber@opensuse.org
- %%post/%%postun are not needed for < 11.4
* Mon Jan 31 2011 gber@opensuse.org
- fix build for < 11.4
* Mon Jan 31 2011 gber@opensuse.org
- updated to version 0.3.0
  + Support libnotify 0.7
  + Copy-friendly URIs with %%20
  + No blocking of typed URLs with adblock
  + Import from Netscape HTML
  + Bookmark im- and export fixes
  + Unit tests cleaned up and updated
  + Correct bookmark and search icon names
  + Better link menu handling
  + Fix Russian keyboard issues
  + Stylesheet parsing improvements
  + Simplify language and panel options
  + Default to DuckDuckGo search
  + No Netscape plugins in extension panel
  + Easy user addon install infobar
- make the -devel subpackage recommend vala
* Wed Jan 26 2011 gber@opensuse.org
- add %%desktop_database_post/%%desktop_database_postun for
  x-scheme-handler
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Fri Dec 24 2010 gber@opensuse.org
- require -lang subpackage
* Fri Dec 24 2010 gber@opensuse.org
- split off -devel package
- package HTML help page
- build API documentation
- use and do not override $RPM_OPT_FLAGS
- improved description/summary
- remove unsupported locales
* Wed Dec 15 2010 prusnak@opensuse.org
- fixed filelist
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.9
  + Add 'Identify As' to Statusbar Features
  + Don't restrict length of HTTP login passwords
  + Implement Find Links by number with '.'
  + Reflect security in icon tooltip
  + Use GIO to determine special URI schemes
  + Upgrade waf (addresses threading issues)
  + Allow clearing HTML5 databases and form history
  + Add --help-execute command line switch
  + Improve private mode, with search and hotkeys
  + Support no-desktop-files and internal Open With
  + Support x-scheme-handler spec
  + Infobar for location and HTML5 database
  + Optimise cookie storing, reduce wakeups
  + Avoid deprecated GTK+ interfaces
  + Remove console in favour of Inspector
  + Simplify and explain cookie preferences
  + Fix Google Reader incompatibility
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.8
  + Re-implement Bookmarks menu and toolbar button
  + Show transferbar even if statusbar is hidden
  + Smart case for inline search while typing
  + Use Alt+Shift+Right instead of Ctrl+Right for Next Page
  + Adding, edit and delete buttons for user scripts/ styles
  + Rename 'Minimize Tab' to 'Show Tab Icon Only'
  + Delete key in completion deletes items
  + Don't show homepage in bookmarkbar
  + Fix crash when using location arrow button
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.7
  + Multiple word completion in location
  + Database backed bookmarks
  + Search bookmark panel and drag bookmarks
  + Bookmarks in address completion
  + Removed bookmarks and history from menubar
  + Add 'Minimize New Tabs' and 'Copy Addresses of Tabs'
  + Refactorings and optimisations in the core
  + Adblock compatibility improvements and speedup
  + Changeable speed dial size
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.6
  + Show a dialogue when quitting while downloading
  + Render icons in errors/ speed dial properly
  + Fix a build error with API documentation
  + Fix error pages in frames, and a related crash
  + Allow more shortcuts or columns in speed dial
  + Add 'Copy All' button to Console panel
* Fri May 21 2010 prusnak@suse.cz
- updated to 0.2.5
  + Keyboard access in speed dial
  + Panels adapt to system icon style
  + Revamp tab focus handling
  + Use new GTK+ 2.20 spinner (throbber) widget
  + Userscripts and -styles can be (de)activated
  + Warn if trying to download with few space
  + Support right button in Mouse Gestures
  + Add (unfinished) 'External Applications' extension
  + Vala support for extensions and tests
  + Yellow location for valid SSL, red for invalid
  + Render XML as source code
  + Provide tools/midori-dev and check-style scripts
  + Implement MIDORI_ADBLOCK for Adblock testing
  + Fix https URI support in Adblock
  + Change 'Autodetect proxy' into 'Proxy type'
  + Update use of deprecated GTK+ API
  + Implement --blocked-uris for kiosk usage
  + Implement --inactivity-reset for kiosk usage
  + Fix typing with dead keys and NumLock
  + Improve parsing in the Feed Panel
  + Add preference 'Allow scripts to open popups'
  + Spawn web apps and private mode with same executable
  + Base Colourful Tabs on icon colours
  + Add Status Clock extension
  + Resolve hosts before trying a search
  + Allow page icons for https
  + Improve handling of special pages
  + Protect against recursive external URI handlers
* Thu Apr  1 2010 prusnak@suse.cz
- updated to 0.2.4
  + Prevent completion from overlapping
  + Fix tab order when restoring session
  + Ignore accidentally middle click search
  + Implement bookmark export to XBEL
  + Provide scroll hotkeys, default to Vim
  + Store and complete search in location
  + Fix opening externally with multiple windows
  + Only use icons in panel buttons
  + Fix build with different GTK+ versions
  + Omit micro version and arch from ident string
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 0.2.3
  + Implement 'Close other tabs' menu item
  + Use new GTK+ accessors where available
  + Allow searching freely in History panel
  + Re-implement completion based on sqlite
  + Re-implement completion suggestion popup
  + Simplify sqlite use towards efficient calls
  + Move panel icons to the bottom
  + Merge Netscape Plugins and Extensions panels
  + Implement 'about:version' special page
  + Implement 'Preferred languages' preference
  + Improve window raising behaviour
  + Allow Ctrl+Right-click to suppress javascript menu
  + Add 'Open link as web app' in context menu
  + Add 'Block image' menu item to Adblock
  + Location progress and compat code refactored
  + Implement 'Paste and proceed' in location
  + Move DNS prefetching into the core
  + Allow selecting and deleting multiple cookies
  + Support attaching/ detaching web inspector
  + Always enable web inspector
  + --diagnostic-dialog command line switch
  + Faster file existence checks
  + Simplified, faster adblock implementation
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.2.2
  + Turn libnotify into a proper build-time dependency
  + Use Ctrl + Return to open tabs from the location entry
  + Support right-click on bookmark menu items
  + Support -e in midori -a and with multiple commands
  + Make Middle click open selection search if needed
  + Make Ctrl+C work as expected again
  + Fix order of History, Trash and Recently opened pages
  + Revise Shortcuts dialogue to fix oddities
  + Perform Form history completion case insensitive
  + Add 'Web Cache' to Delete Private data dialogue
  + Load accels from /etc/xdg if present
  + Improve XBEL format compatibility and performance
  + Fix inline find by correcting key handling
  + Add option to open panels in separate windows
  + Support Portrait orientation in Fremantle
  + Support Hildon MIME and URI handling
  + Check status before caching in Web Cache
  + Show popup menu on news feed icon if needed
  + Support Colourful Tabs with Tab Panel
  + Tweak sqlite and dbus handling for Win32
  + 'Run as web app' and 'Show in toolbar' for bookmarks
  + Add 'Small icons' toolbar style
  + Fix build with Glib < 2.20 and GTK+ < 2.12
  + Add Import bookmarks for XBEL, Opera and RDF
  + Add Open Link in Foreground/ Background Tab menu
  + Allow closing all tabs
  + Hildon file chooser support
* Sat Nov 14 2009 prusnak@suse.cz
- updated to 0.2.1
  + Fix Mouse Gestures to work after activation
  + Explicitly link to X11 to support gold
  + Implement various Hildon specific features
  + Hide the navigationbar in fullscreen
  + Implement permanent storage of form history
  + Support keyboard shortcuts like Ctrl+Tab or "a"
  + Handle SIGHUP, SIGINT, SIGTERM and SIGQUIT
  + Make creation of new windows fast
  + Introduce the Tab History List extension
  + Load icons laziy at startup to speed up startup
  + Introduce a Web Cache extension
  + Refactor and tweak the Preferences dialogue
  + Implement combos to choose external applications
* Wed Nov  4 2009 prusnak@suse.cz
- fix build
* Fri Oct 16 2009 prusnak@suse.cz
- updated to 0.2.0
  + (Kinetic) drag scrolling on touchscreen devices
  + Workaround a speed dial crasher
  + Faster Adblock with element blocking, for all WebKitGTK+ versions
  + Stripped menu, toolbar and tap on hold on Maemo, and 5.0 menu support
  + Add a DNS prefetching extension
  + Better IDN handling
  + Add a form history extension
  + Restore scrolling positions from the session
  + Keep typed address when switching tabs
  + Avoid storing duplicate history items per day
  + Fix multiple duplicate HTTP authentication dialogs
  + Pass mailto: links to the email client
  + Improve context menu with WebKitGTK+ 1.1.15
  + Checkbox "Remember password" in HTTP authentication
  + Fix a crasher when modifying bookmarks
  + Support page icons other than favicon.ico
  + iPhone identity in Network preferences
* Mon Sep 14 2009 prusnak@suse.cz
- updated to 0.1.10
  + Fix freezing when opening multiple windows
  + Revamp Adblock with WebKitGTK+ 1.1.14 API
  + Greatly improve the address completion
  + Always show news feed icon
  + Better handling of feeds in the feed panel
  + Add Gtk+ and WebKit version to the About dialog
  + Improve tab panel and support minimized tabs
  + Implement disabling of extensions in crahs dialog
  + Don't make the web inspector transient
  + Tidy up the Preferences a bit
  + Load default bookmarks and config from /etc
  + Do not use xprop at runtime
  + Use GNOME proxy server if libsoup-gnome is installed
  + Integrate Save As with transfers
  + Save HTTP logins in a text file
  + Support Undo and Redo with WebKitGTK+ 1.1.14
* Wed Aug 12 2009 prusnak@suse.cz
- updated to 0.1.9
  + Preserve navigation history with new tabs
  + Implement clearing private data when quitting
  + Ellipsize and show close icons in the tab panel
  + Allow hiding panel operating controls
  + Integrate Tools with the compact menu
  + Fix User scripts, User styles and Plugins panel
  + Remove the bookmarkbar popup
  + Add New Tab to the tab context menu
  + Implement minimizing tabs
* Thu Jul 23 2009 prusnak@suse.cz
- updated to 0.1.8
  + Initial support for extension unit tests
  + Set a "browser" role on browser windows
  + Support typing search tokens to open websites
  + Fix focus loss when switching search engines
  + Rewrite Netscape Plugins panel backed by javascript
  + Implement a compact menu if menubar is hidden
  + Provide a context menu for tab labels
  + Implement Tab Panel as a tabbar replacement
  + Remember the last active tab
  + Read and write XBEL metadata internally
  + Implement -e, --execute to perform commands
  + Support socket based single instance
  + Move Go button inside the location entry
  + Fix the ident string after Midori updates
  + Bind Alt + n to switching to the n-th tab
  + Revisit conflicting mnemonics
  + Add a Toolbar Editor extension
  + Add a Shortcut Editor extension
  + Implement context menu in the Transfers panel
  + Simplified Extensions and Addons panels with tick marks
  + Fix Mouse Gestures often ignoreing gestures
  + Use one cookie manager model in all windows
  + Support building Midori for Win32
  + Add an entry to specify Fixed-Width font size
  + Implement Save As in the download dialog
  + Use one history model in all windows
* Mon Jun  1 2009 prusnak@suse.cz
- updated to 0.1.7
  + Save the activation status of extensions
  + Catch and ignore mouse buttons meant for horizontal scrolling
  + Improve panel detaching and how panels handle it
  + Add a Feed Panel extension
  + Add a Fixed-width Font Family preference
  + Support spell checking
  + Implement (optional) Speed dial feature
  + Support nicer error pages with WebKitGTK+ 1.1.6
  + Implement middle click to open menu items in tabs
  + Implement -s, --snapshot command line switch
  + Use libnotify (runtime dependency) for finished transfers
  + Add a Go button to the address entry
  + Always append tabs opened via middle/ double click on the tab bar
  + Implement Open new pages in: New window preference
  + Implement inline find with direct '.' and '/' hotkeys
  + Add basic support for @-moz-document in user styles
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 0.1.6
  + Add Delete All to transferbar
  + Show search in context menu
  + Implement 'Default' search engine
  + Show only icons in Statusbar Features
  + Implement Clear private data
  + Support News Feed icon and external aggregator
  + Fix reloading of Not found pages
  + Fixup spaces when middle click opening
  + Fix possibly wrong identificaton string
  + Optionally search engines in completion
  + Optionally Gtk 2.16 entry progress and icon
  + Experimental panel detaching
  + Support external download manager again
  + Implement '-a', '--app' argument
  + Implement '-c', '--config' argument
  + Fix a bookmark saving issue
  + Support data: URIs in the address entry
  + Several performance and memory leak fixes
  + Load cookies idle to accelerate startup
  + Support mailto: links
  + Save tab reordering in the session
  + Add a Cookie Manager extension
  + Fix crashers in Colourful Tabs
* Mon Mar 23 2009 prusnak@suse.cz
- updated to 0.1.5
  + Add a Colorful Tabs extension
  + Support downloading with WebKitGTK+ 1.1.3
  + Load and save settings of extensions
  + Drop internal source view
  + Require WebKitGTK+ 1.1.1, Glib 2.16 and libsoup 2.25.2
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 0.1.4
  + Automatic inline find can be disabled
  + Implement an Encoding menu
  + Add Open all in Tabs for bookmarks and history
  + Bookmarks can be moved to other folders
  + Fix blank page 'loading' and HTTP authentication
  + Display history dates in the local format
  + Allow editing of completion items
* Mon Feb 23 2009 prusnak@suse.cz
- updated to 0.1.3
  + Sidepanel can be aligned on the right
  + Bookmarks can be organized in folders
  + Support find as you type
  + Support international domain names
  + Tweak location completion
  + Provide default search engines
  + Integrate with Maemo if available
  + Implement Mouse Gestures extension
  + Implement a Plugins panel
  + Editing the toolbar via a context menu
  + Introduce Zoom Text and Images preference
* Wed Jan 28 2009 prusnak@suse.cz
- updated to 0.1.2
  + Open new tabs by clicking on the tabbar
  + Refactor and speed up location completion
  + Show a Crash dialog after crashes
  + Dynamically save files when needed
  + Support Back/ Forward mouse buttons
  + Support javascript: bookmarklets
  + Implement Proxy and Identification string
  + Implement cookie storage on disk
  + Remove autotooled build system
  + Add a new Extensions panel
  + Support javascript bookmarklets
  + Implement opening of new windows
  + Display tooltips in Preferences
* Mon Dec  1 2008 prusnak@suse.cz
- updated to 0.1.1
  + Reimplement page holder as an extension
  + Introduce a C extension interface
  + Introduce unit tests for automated testing
  + Implement history based location completion
  + Support the Web Inspector in new WebKit versions
  + Bookmarkbar properly reflects changes
  + Improve overall OS X integration
  + Add a Text Editor Preference
  + Add a Compat sidebar Preference
  + Add an Open external pages in Preference
  + Implement source view and cached favicons with libsoup
* Mon Oct 20 2008 ajorgensen@novell.com
- Update to 0.1.0
  * Customizable toolbar
  * Error pages
  * The beginnings of user documentation
  * Overall various interface improvements
  * History support in the form of a panel and allowing to hide the
    menubar
- Update to 0.0.21
  * If you hide the statusbar Midori will now show the loading
    progress inside the location entry
  * Typing an address in the location and pressing Alt + Enter will
    open the address in a new tab
* Mon Aug 25 2008 ajorgensen@novell.com
- Update to 0.0.20
  * Support for using a single instance (via libunique, not enabled)
  * Support for user styles
  * Extension icon
* Fri Aug  8 2008 ajorgensen@novell.com
- Initial upload (version 0.0.19)
